@@ -381,7 +381,7 @@ class Space_evenly_per_stroke(object):
             if len(stroke) < 2:
                 # Don't do anything if there are less than 2 points
                 new_stroke = stroke
-            if 2 <= len(stroke) <= 3:
+            elif 2 <= len(stroke) <= 3:
                 # Linear interpolation for 2 or 3 points
                 # TODO: This is much code duplication. Can this be done better?
                 stroke = sorted(stroke, key=lambda p: p['time'])
